<?php
/**
 * @file
 * Theme and preprocess functions for the Video.js module.
 */

/**
 * Preprocess function for videojs.tpl.php when using a playlist.
 */
function template_preprocess_videojs_formatter_videojs(&$vars) {
  videojs_add();

  $vars['items'] = array();
  $vars['width'] = intval(variable_get('videojs_width', 640));
  $vars['height'] = intval(variable_get('videojs_height', 264));
  $field_name = $vars['element']['#field_name'];
  $node = $vars['element']['#node'];

  foreach ((array) $node->$field_name as $item) {
    $item['videotype'] = _videojs_get_filetype($item['filemime']);
    if ($item['videotype'] == NULL) {
      continue;
    }

    if (!isset($item['url'])) {
      $item['url'] = _videojs_create_url($item['filepath']);
    }

    $vars['items'][] = $item;
  }

  $vars['items'] = array_merge($items_mp4, $items_others); // mp4 listed first

  $vars['player_id'] = 'videojs-' . $vars['element']['#node']->nid . '-' . str_replace('_', '-', $vars['element']['#field_name']);
  $vars['poster'] = NULL;

  $poster_field = variable_get('videojs_' . $node->type, 'video_module');
  if ($poster_field == 'video_module') {
    if (!empty($vars['items'][0]['data']['video_thumb'])) {
      // Video module present, retrieving description and poster image from first video
      $vars['poster'] = _videojs_create_url($vars['items'][0]['data']['video_thumb']);
    }
  }
  else {
    // Grab any poster image from a field defined in videojs admin settings
    if (!empty($node->$poster_field)) {
      $image = $node->{$poster_field}[0]; // take the first image from field
      $vars['poster'] = _videojs_create_url($image['filepath']);
    }
  }
}

/**
 * Preprocess function for videojs.tpl.php when displaying a view as a playlist.
 */
function template_preprocess_videojs_view(&$vars) {
  videojs_add();
  $vars['player_id'] = 'videojs-view-' . str_replace('_', '-', $vars['view']->name);
}

/**
 * Preprocess function for videojs.tpl.php when displaying a view as a playlist.
 */
function template_preprocess_videojs(&$vars) {
  videojs_add();

  $items = $vars['items'];

  $vars['player_id'] = 'videojs-' . str_replace('_', '-', $vars['player_id']);
  $vars['poster'] = _videojs_create_url($vars['items']['thumbnail']['filepath']);
  $vars['width'] = intval($vars['attributes']['width']);
  $vars['height'] = intval($vars['attributes']['height']);
  $vars['autoplay'] = !!variable_get('videojs_autoplay', FALSE);
  $vars['items'] = array();

  foreach ($items as $item) {
    $item['videotype'] = _videojs_get_filetype($item['filemime']);
    if ($item['videotype'] == NULL) {
      continue;
    }

    if (!isset($item['url'])) {
      $item['url'] = _videojs_create_url($item['filepath']);
    }

    $vars['items'][] = $item;
  }
}

function _videojs_create_url($filepath) {
  if (strncmp($filepath, 'http:', 5) === 0 || strncmp($filepath, 'https:', 6) === 0) {
    return $filepath;
  }

  return file_create_url(drupal_urlencode($filepath));
}

function _videojs_get_filetype($filemime) {
  switch (drupal_strtolower($filemime)) {
    case 'video/mp4':
    case 'video/quicktime':
      return 'video/mp4';
    case 'video/ogg':
    case 'application/ogg':
      return 'video/ogg';
    case 'video/webm':
    case 'application/octet-stream':
      return 'video/webm';
    case 'video/flv':
    case 'video/x-flv':
      return 'video/flv';
  }

  return NULL;
}
